diff --git a/build/deb/conf.php.install b/build/deb/conf.php.install
index d392d431955..78195f27006 100755
--- a/build/deb/conf.php.install
+++ b/build/deb/conf.php.install
@@ -136,7 +136,7 @@ $dolibarr_main_db_collation='latin1_swedish_ci';
# This parameter contains the way authentication is done.
# If value "ldap" is used, you must also set parameters dolibarr_main_auth_ldap_*
# Default value: dolibarr
-# Possible values: Any values found in files in htdocs/includes/login directory after
+# Possible values: Any values found in files in htdocs/core/login directory after
# the "function_" string and before the ".php" string. You can also separate several
# values using a ",". In this case, Dolibarr will check login/pass for each value in
# order defined into value. However, note that this can't work with all values.
diff --git a/build/makepack-dolibarrmodule.conf b/build/makepack-dolibarrmodule.conf
index 287b4a58d55..8fddcd07a3b 100644
--- a/build/makepack-dolibarrmodule.conf
+++ b/build/makepack-dolibarrmodule.conf
@@ -8,8 +8,8 @@
# Setup: Go on Dolibarr setup - modules page to enable module.
#
# Files in module
-htdocs/includes/modules/modMyModule.class.php
-htdocs/includes/triggers/interface_mymodule.class.php
+htdocs/core/modules/modMyModule.class.php
+htdocs/core/triggers/interface_mymodule.class.php
htdocs/mymodule/page1.php
htdocs/mymodule/page2.php
htdocs/mymodule/sql/script1.sql
diff --git a/build/tgz/tar_exclude.txt b/build/tgz/tar_exclude.txt
index 12ba7ebbf39..78b2360b27b 100644
--- a/build/tgz/tar_exclude.txt
+++ b/build/tgz/tar_exclude.txt
@@ -45,15 +45,15 @@ htdocs/includes/treemenu/docs
htdocs/includes/treemenu/images
htdocs/includes/treemenu/imagesAlt
htdocs/includes/treemenu/imagesAlt2
-htdocs/includes/modules/modBookmark4u.class.php
-htdocs/includes/modules/modDocument.class.php
-htdocs/includes/modules/modDroitPret.class.php
-htdocs/includes/modules/modEditeur.class.php
-htdocs/includes/modules/modPostnuke.class.php
-htdocs/includes/modules/modTelephonie.class.php
-htdocs/includes/triggers/interface_user.class.php
-htdocs/includes/triggers/interface_contractfrombill.class.php-NORUN
-htdocs/includes/triggers/interface_modEditeur_Editeur.class.php-NORUN
+htdocs/core/modules/modBookmark4u.class.php
+htdocs/core/modules/modDocument.class.php
+htdocs/core/modules/modDroitPret.class.php
+htdocs/core/modules/modEditeur.class.php
+htdocs/core/modules/modPostnuke.class.php
+htdocs/core/modules/modTelephonie.class.php
+htdocs/core/triggers/interface_user.class.php
+htdocs/core/triggers/interface_contractfrombill.class.php-NORUN
+htdocs/core/triggers/interface_modEditeur_Editeur.class.php-NORUN
htdocs/includes/tcpdf/fonts/utils
htdocs/includes/tcpdf/fonts/free*.ctg.z
htdocs/includes/tcpdf/fonts/free*.z
diff --git a/build/zip/zip_exclude.txt b/build/zip/zip_exclude.txt
index e94edb93793..e6db7bddcc0 100644
--- a/build/zip/zip_exclude.txt
+++ b/build/zip/zip_exclude.txt
@@ -46,16 +46,16 @@
*/htdocs/includes/treemenu/images/*
*/htdocs/includes/treemenu/imagesAlt/*
*/htdocs/includes/treemenu/imagesAlt2/*
-*/htdocs/includes/modules/modBarcode.class.php
-*/htdocs/includes/modules/modBookmark4u.class.php
-*/htdocs/includes/modules/modClickToDial.class.php
-*/htdocs/includes/modules/modDocument.class.php
-*/htdocs/includes/modules/modDomain.class.php
-*/htdocs/includes/modules/modDroitPret.class.php
-*/htdocs/includes/modules/modEditeur.class.php
-*/htdocs/includes/modules/modPostnuke.class.php
-*/htdocs/includes/triggers/interface_user.class.php
-*/htdocs/includes/triggers/interface_contractfrombill.class.php-NORUN
+*/htdocs/core/modules/modBarcode.class.php
+*/htdocs/core/modules/modBookmark4u.class.php
+*/htdocs/core/modules/modClickToDial.class.php
+*/htdocs/core/modules/modDocument.class.php
+*/htdocs/core/modules/modDomain.class.php
+*/htdocs/core/modules/modDroitPret.class.php
+*/htdocs/core/modules/modEditeur.class.php
+*/htdocs/core/modules/modPostnuke.class.php
+*/htdocs/core/triggers/interface_user.class.php
+*/htdocs/core/triggers/interface_contractfrombill.class.php-NORUN
*/htdocs/includes/tcpdf/fonts/utils/*
*/htdocs/includes/tcpdf/fonts/free*.ctg.z
*/htdocs/includes/tcpdf/fonts/free*.z
diff --git a/dev/initdata/generate-propale.php b/dev/initdata/generate-propale.php
index d7b97936e24..15df2afa79f 100644
--- a/dev/initdata/generate-propale.php
+++ b/dev/initdata/generate-propale.php
@@ -106,9 +106,9 @@ if ($resql)
$user->rights->propale->valider=1;
-if (! empty($conf->global->PROPALE_ADDON) && is_readable(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
+if (! empty($conf->global->PROPALE_ADDON) && is_readable(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
{
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php");
}
$i=0;
diff --git a/htdocs/adherents/cartes/carte.php b/htdocs/adherents/cartes/carte.php
index b3bc6a9a68f..ad783039514 100755
--- a/htdocs/adherents/cartes/carte.php
+++ b/htdocs/adherents/cartes/carte.php
@@ -25,8 +25,8 @@
require("../../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/core/lib/files.lib.php");
require_once(DOL_DOCUMENT_ROOT."/adherents/class/adherent.class.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/member/cards/modules_cards.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/member/labels/modules_labels.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/member/cards/modules_cards.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/member/labels/modules_labels.php");
$langs->load("members");
$langs->load("errors");
diff --git a/htdocs/admin/barcode.php b/htdocs/admin/barcode.php
index db838c9b7f7..66d4268ba38 100644
--- a/htdocs/admin/barcode.php
+++ b/htdocs/admin/barcode.php
@@ -108,7 +108,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/barcode/";
+ $dir = $dirroot . "/core/modules/barcode/";
$handle=@opendir($dir);
if (is_resource($handle))
@@ -193,7 +193,7 @@ if ($resql)
// Chargement de la classe de codage
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir=$dirroot . "/includes/modules/barcode/";
+ $dir=$dirroot . "/core/modules/barcode/";
$result=@include_once($dir.$obj->coder.".modules.php");
//print $dir.$obj->coder.".modules.php - ".$result;
if ($result) break;
diff --git a/htdocs/admin/boxes.php b/htdocs/admin/boxes.php
index 3a6ad26b40c..45d003a6acc 100644
--- a/htdocs/admin/boxes.php
+++ b/htdocs/admin/boxes.php
@@ -23,7 +23,7 @@
*/
require("../main.inc.php");
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
include_once(DOL_DOCUMENT_ROOT."/core/lib/admin.lib.php");
$langs->load("admin");
@@ -277,12 +277,12 @@ if ($resql)
{
$boxname = $regs[1];
$module = $regs[2];
- $sourcefile = "/".$module."/includes/boxes/".$boxname.".php";
+ $sourcefile = "/".$module."/core/boxes/".$boxname.".php";
}
else
{
$boxname=preg_replace('/.php$/i','',$obj->file);
- $sourcefile = "/includes/boxes/".$boxname.".php";
+ $sourcefile = "/core/boxes/".$boxname.".php";
}
dol_include_once($sourcefile);
@@ -393,12 +393,12 @@ if ($resql)
{
$boxname = $regs[1];
$module = $regs[2];
- $sourcefile = "/".$module."/includes/boxes/".$boxname.".php";
+ $sourcefile = "/".$module."/core/boxes/".$boxname.".php";
}
else
{
$boxname=preg_replace('/.php$/i','',$obj->file);
- $sourcefile = "/includes/boxes/".$boxname.".php";
+ $sourcefile = "/core/boxes/".$boxname.".php";
}
dol_include_once($sourcefile);
diff --git a/htdocs/admin/commande.php b/htdocs/admin/commande.php
index 2ad6ec754da..d5e71e6ade8 100644
--- a/htdocs/admin/commande.php
+++ b/htdocs/admin/commande.php
@@ -72,7 +72,7 @@ if ($action == 'specimen')
$commande->initAsSpecimen();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/commande/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/commande/";
$file = "pdf_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -243,7 +243,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/commande/";
+ $dir = $dirroot . "/core/modules/commande/";
if (is_dir($dir))
{
@@ -258,7 +258,7 @@ foreach ($conf->file->dol_document_root as $dirroot)
{
$file = substr($file, 0, dol_strlen($file)-4);
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/commande/".$file.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/commande/".$file.".php");
$module = new $file;
@@ -374,7 +374,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/commande/";
+ $dir = $dirroot . "/core/modules/commande/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/confexped.php b/htdocs/admin/confexped.php
index ec3415f339f..8c67fd28cf5 100644
--- a/htdocs/admin/confexped.php
+++ b/htdocs/admin/confexped.php
@@ -65,7 +65,7 @@ else if ($action == 'disable_delivery')
/*
* Affiche page
*/
-$dir = DOL_DOCUMENT_ROOT."/includes/modules/expedition/";
+$dir = DOL_DOCUMENT_ROOT."/core/modules/expedition/";
$html=new Form($db);
llxHeader("","");
diff --git a/htdocs/admin/contract.php b/htdocs/admin/contract.php
index 285887d15ba..a4ac55ac3e8 100644
--- a/htdocs/admin/contract.php
+++ b/htdocs/admin/contract.php
@@ -80,7 +80,7 @@ if ($action == 'setmod')
llxHeader();
-$dir=DOL_DOCUMENT_ROOT."/includes/modules/contract/";
+$dir=DOL_DOCUMENT_ROOT."/core/modules/contract/";
$html=new Form($db);
$linkback=''.$langs->trans("BackToModuleList").'';
@@ -101,7 +101,7 @@ print "\n";
clearstatcache();
-$dir = "../includes/modules/contract/";
+$dir = "../core/modules/contract/";
$handle = opendir($dir);
if (is_resource($handle))
{
@@ -113,7 +113,7 @@ if (is_resource($handle))
{
$file = substr($file, 0, dol_strlen($file)-4);
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/contract/".$file.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/contract/".$file.".php");
$module = new $file;
diff --git a/htdocs/admin/dons.php b/htdocs/admin/dons.php
index 632f4a9ac5b..54a5d208a5b 100644
--- a/htdocs/admin/dons.php
+++ b/htdocs/admin/dons.php
@@ -44,7 +44,7 @@ if ($_GET["action"] == 'specimen')
$don->initAsSpecimen();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/dons/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/dons/";
$file = $modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -126,7 +126,7 @@ if ($_GET["action"] == 'del')
* View
*/
-$dir = "../includes/modules/dons/";
+$dir = "../core/modules/dons/";
$html=new Form($db);
llxHeader('',$langs->trans("DonationsSetup"),'DonConfiguration');
diff --git a/htdocs/admin/expedition.php b/htdocs/admin/expedition.php
index 245a4ea1146..471b48f5226 100644
--- a/htdocs/admin/expedition.php
+++ b/htdocs/admin/expedition.php
@@ -58,7 +58,7 @@ if ($action == 'specimen')
//$exp->fetch_commande();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/expedition/pdf/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/expedition/pdf/";
$file = "pdf_expedition_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -161,7 +161,7 @@ if ($action == 'setmethod' || $action== 'setmod')
$moduleid=GETPOST("moduleid");
$statut=GETPOST("statut");
- require_once(DOL_DOCUMENT_ROOT."/includes/modules/expedition/methode_expedition_$module.modules.php");
+ require_once(DOL_DOCUMENT_ROOT."/core/modules/expedition/methode_expedition_$module.modules.php");
$classname = "methode_expedition_$module";
$expem = new $classname($db);
@@ -350,7 +350,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/expedition/";
+ $dir = $dirroot . "/core/modules/expedition/";
if (is_dir($dir))
{
@@ -365,7 +365,7 @@ foreach ($conf->file->dol_document_root as $dirroot)
{
$file = substr($file, 0, dol_strlen($file)-4);
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/expedition/".$file.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/expedition/".$file.".php");
$module = new $file;
@@ -486,7 +486,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/expedition/pdf/";
+ $dir = $dirroot . "/core/modules/expedition/pdf/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/facture.php b/htdocs/admin/facture.php
index 4530485501a..e7a96876c60 100644
--- a/htdocs/admin/facture.php
+++ b/htdocs/admin/facture.php
@@ -77,7 +77,7 @@ if ($action == 'specimen')
$facture->initAsSpecimen();
// Load template
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/facture/doc/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/facture/doc/";
$file = "pdf_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -345,7 +345,7 @@ clearstatcache();
$var=true;
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/facture/";
+ $dir = $dirroot . "/core/modules/facture/";
if (is_dir($dir))
{
@@ -512,7 +512,7 @@ foreach ($conf->file->dol_document_root as $dirroot)
{
foreach (array('','/doc') as $valdir)
{
- $dir = $dirroot . "/includes/modules/facture".$valdir;
+ $dir = $dirroot . "/core/modules/facture".$valdir;
if (is_dir($dir))
{
diff --git a/htdocs/admin/fichinter.php b/htdocs/admin/fichinter.php
index 5b454bfcb0d..6ee36a8434f 100644
--- a/htdocs/admin/fichinter.php
+++ b/htdocs/admin/fichinter.php
@@ -106,7 +106,7 @@ if ($action == 'specimen')
$inter->initAsSpecimen();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/fichinter/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/fichinter/";
$file = "pdf_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -242,7 +242,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/fichinter/";
+ $dir = $dirroot . "/core/modules/fichinter/";
if (is_dir($dir))
{
@@ -360,7 +360,7 @@ clearstatcache();
$var=true;
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/fichinter/";
+ $dir = $dirroot . "/core/modules/fichinter/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/fournisseur.php b/htdocs/admin/fournisseur.php
index d62024293bc..f22b81a3697 100644
--- a/htdocs/admin/fournisseur.php
+++ b/htdocs/admin/fournisseur.php
@@ -77,7 +77,7 @@ if ($action == 'specimen') // For orders
$commande->thirdparty=$specimenthirdparty;
// Charge le modele
- $dir = "/includes/modules/supplier_order/pdf/";
+ $dir = "/core/modules/supplier_order/pdf/";
$file = "pdf_".$modele.".modules.php";
$file = dol_buildpath($dir.$file);
if (file_exists($file))
@@ -114,7 +114,7 @@ if ($action == 'specimenfacture') // For invoices
$facture->thirdparty=$specimenthirdparty; // Define who should has build the invoice (so the supplier)
// Charge le modele
- $dir = "/includes/modules/supplier_invoice/pdf/";
+ $dir = "/core/modules/supplier_invoice/pdf/";
$file = "pdf_".$modele.".modules.php";
$file = dol_buildpath($dir.$file);
if (file_exists($file))
@@ -269,7 +269,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/supplier_order/";
+ $dir = $dirroot . "/core/modules/supplier_order/";
if (is_dir($dir))
{
@@ -404,7 +404,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/supplier_order/pdf/";
+ $dir = $dirroot . "/core/modules/supplier_order/pdf/";
if (is_dir($dir))
{
@@ -537,7 +537,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/supplier_invoice/pdf/";
+ $dir = $dirroot . "/core/modules/supplier_invoice/pdf/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/livraison.php b/htdocs/admin/livraison.php
index 6a5a6819bf0..9577de2db81 100644
--- a/htdocs/admin/livraison.php
+++ b/htdocs/admin/livraison.php
@@ -70,7 +70,7 @@ if ($action == 'specimen')
//$sending->fetch_commande();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/livraison/pdf/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/livraison/pdf/";
$file = "pdf_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -238,7 +238,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/livraison/";
+ $dir = $dirroot . "/core/modules/livraison/";
if (is_dir($dir))
{
@@ -252,7 +252,7 @@ foreach ($conf->file->dol_document_root as $dirroot)
{
$file = substr($file, 0, dol_strlen($file)-4);
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/livraison/".$file.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/livraison/".$file.".php");
$module = new $file;
@@ -371,7 +371,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/livraison/pdf/";
+ $dir = $dirroot . "/core/modules/livraison/pdf/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/menus.php b/htdocs/admin/menus.php
index 54542b98095..356828b7bdc 100644
--- a/htdocs/admin/menus.php
+++ b/htdocs/admin/menus.php
@@ -38,9 +38,9 @@ $langs->load("other");
// Security check
if (!$user->admin) accessforbidden();
-$dirtop = "/includes/menus/standard";
-$dirleft = "/includes/menus/standard";
-$dirsmartphone = "/includes/menus/smartphone";
+$dirtop = "/core/menus/standard";
+$dirleft = "/core/menus/standard";
+$dirsmartphone = "/core/menus/smartphone";
// Cette page peut etre longue. On augmente le delai autorise.
@@ -77,7 +77,7 @@ if (isset($_POST["action"]) && $_POST["action"] == 'update' && empty($_POST["can
foreach ($listofmenuhandler as $key => $val)
{
// Load sql init_menu_handler.sql file
- $dir = "/includes/menus/";
+ $dir = "/core/menus/";
$file='init_menu_'.$key.'.sql';
$fullpath=dol_buildpath($dir.$file);
diff --git a/htdocs/admin/menus/edit.php b/htdocs/admin/menus/edit.php
index df5d7c740f3..5c8dc99ab0f 100644
--- a/htdocs/admin/menus/edit.php
+++ b/htdocs/admin/menus/edit.php
@@ -33,9 +33,9 @@ $langs->load("admin");
if (! $user->admin)
accessforbidden();
-$dirtop = "/includes/menus/standard";
-$dirleft = "/includes/menus/standard";
-$dirsmartphone = "/includes/menus/smartphone";
+$dirtop = "/core/menus/standard";
+$dirleft = "/core/menus/standard";
+$dirsmartphone = "/core/menus/smartphone";
$dirmenu = array($dirleft,$dirsmartphone);
diff --git a/htdocs/admin/menus/index.php b/htdocs/admin/menus/index.php
index 71531c2f4f7..b528f7e374f 100644
--- a/htdocs/admin/menus/index.php
+++ b/htdocs/admin/menus/index.php
@@ -33,9 +33,9 @@ $langs->load("admin");
if (! $user->admin)
accessforbidden();
-$dirtop = "/includes/menus/standard";
-$dirleft = "/includes/menus/standard";
-$dirsmartphone = "/includes/menus/smartphone";
+$dirtop = "/core/menus/standard";
+$dirleft = "/core/menus/standard";
+$dirsmartphone = "/core/menus/smartphone";
$dirmenu = array($dirleft,$dirsmartphone);
diff --git a/htdocs/admin/modules.php b/htdocs/admin/modules.php
index c51b14859dc..fb85c0016be 100644
--- a/htdocs/admin/modules.php
+++ b/htdocs/admin/modules.php
@@ -85,7 +85,7 @@ $j = 0; // j is module number. Automatically affected if module number not defin
foreach ($conf->file->dol_document_root as $type => $dirroot)
{
- $modulesdir[] = $dirroot . "/includes/modules/";
+ $modulesdir[] = $dirroot . "/core/modules/";
if ($type == 'alt')
{
@@ -96,9 +96,9 @@ foreach ($conf->file->dol_document_root as $type => $dirroot)
{
if (is_dir($dirroot.'/'.$file) && substr($file, 0, 1) <> '.' && substr($file, 0, 3) <> 'CVS' && $file != 'includes')
{
- if (is_dir($dirroot . '/' . $file . '/includes/modules/'))
+ if (is_dir($dirroot . '/' . $file . '/core/modules/'))
{
- $modulesdir[] = $dirroot . '/' . $file . '/includes/modules/';
+ $modulesdir[] = $dirroot . '/' . $file . '/core/modules/';
}
}
}
diff --git a/htdocs/admin/notification.php b/htdocs/admin/notification.php
index 6f5eec72b5b..9855c45a0dc 100644
--- a/htdocs/admin/notification.php
+++ b/htdocs/admin/notification.php
@@ -24,7 +24,7 @@
require("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/core/lib/admin.lib.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/triggers/interface_modNotification_Notification.class.php");
+require_once(DOL_DOCUMENT_ROOT."/core/triggers/interface_modNotification_Notification.class.php");
$langs->load("admin");
$langs->load("other");
diff --git a/htdocs/admin/perms.php b/htdocs/admin/perms.php
index 67a1792142e..f874f6ed074 100644
--- a/htdocs/admin/perms.php
+++ b/htdocs/admin/perms.php
@@ -83,7 +83,7 @@ $modulesdir = array();
foreach ($conf->file->dol_document_root as $type => $dirroot)
{
- $modulesdir[] = $dirroot . "/includes/modules/";
+ $modulesdir[] = $dirroot . "/core/modules/";
if ($type == 'alt')
{
@@ -94,9 +94,9 @@ foreach ($conf->file->dol_document_root as $type => $dirroot)
{
if (is_dir($dirroot.'/'.$file) && substr($file, 0, 1) <> '.' && substr($file, 0, 3) <> 'CVS' && $file != 'includes')
{
- if (is_dir($dirroot . '/' . $file . '/includes/modules/'))
+ if (is_dir($dirroot . '/' . $file . '/core/modules/'))
{
- $modulesdir[] = $dirroot . '/' . $file . '/includes/modules/';
+ $modulesdir[] = $dirroot . '/' . $file . '/core/modules/';
}
}
}
diff --git a/htdocs/admin/project.php b/htdocs/admin/project.php
index 321bb024b42..52a9df582ff 100644
--- a/htdocs/admin/project.php
+++ b/htdocs/admin/project.php
@@ -69,7 +69,7 @@ if ($action == 'specimen')
$project->initAsSpecimen();
// Charge le modele
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/project/pdf/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/project/pdf/";
$file = "pdf_".$modele.".modules.php";
if (file_exists($dir.$file))
{
@@ -183,7 +183,7 @@ print "
";
// Project numbering module
-$dir = DOL_DOCUMENT_ROOT."/includes/modules/project/";
+$dir = DOL_DOCUMENT_ROOT."/core/modules/project/";
print_titre($langs->trans("ProjectsNumberingModules"));
@@ -209,7 +209,7 @@ if (is_resource($handle))
{
$file = substr($file, 0, dol_strlen($file)-4);
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/project/".$file.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/project/".$file.".php");
$module = new $file;
@@ -280,7 +280,7 @@ print '
';
* Modeles documents for projects
*/
-$dir = DOL_DOCUMENT_ROOT.'/includes/modules/project/pdf/';
+$dir = DOL_DOCUMENT_ROOT.'/core/modules/project/pdf/';
print_titre($langs->trans("ProjectsModelModule"));
diff --git a/htdocs/admin/propale.php b/htdocs/admin/propale.php
index 63ba2e37ca7..9dfe9bf979a 100644
--- a/htdocs/admin/propale.php
+++ b/htdocs/admin/propale.php
@@ -71,7 +71,7 @@ if ($action == 'specimen')
$propal->initAsSpecimen();
// Charge le modele
- $dir = "/includes/modules/propale/";
+ $dir = "/core/modules/propale/";
$file = "pdf_propale_".$modele.".modules.php";
$file = dol_buildpath($dir.$file);
if (file_exists($file))
@@ -276,7 +276,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/propale/";
+ $dir = $dirroot . "/core/modules/propale/";
if (is_dir($dir))
{
@@ -406,7 +406,7 @@ clearstatcache();
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot . "/includes/modules/propale/";
+ $dir = $dirroot . "/core/modules/propale/";
if (is_dir($dir))
{
diff --git a/htdocs/admin/security.php b/htdocs/admin/security.php
index 142bb63e919..2d50dc77679 100644
--- a/htdocs/admin/security.php
+++ b/htdocs/admin/security.php
@@ -211,7 +211,7 @@ print '';
print '';
// Charge tableau des modules generation
-$dir = "../includes/modules/security/generate";
+$dir = "../core/modules/security/generate";
clearstatcache();
$handle=opendir($dir);
$i=1;
diff --git a/htdocs/admin/system/modules.php b/htdocs/admin/system/modules.php
index 08bcd0329ed..84c8340ff12 100644
--- a/htdocs/admin/system/modules.php
+++ b/htdocs/admin/system/modules.php
@@ -49,7 +49,7 @@ $modules_files = array();
foreach ($conf->file->dol_document_root as $type => $dirroot)
{
- $modulesdir[] = $dirroot . "/includes/modules/";
+ $modulesdir[] = $dirroot . "/core/modules/";
if ($type == 'alt')
{
@@ -60,9 +60,9 @@ foreach ($conf->file->dol_document_root as $type => $dirroot)
{
if (is_dir($dirroot.'/'.$file) && substr($file, 0, 1) <> '.' && substr($file, 0, 3) <> 'CVS' && $file != 'includes')
{
- if (is_dir($dirroot . '/' . $file . '/includes/modules/'))
+ if (is_dir($dirroot . '/' . $file . '/core/modules/'))
{
- $modulesdir[] = $dirroot . '/' . $file . '/includes/modules/';
+ $modulesdir[] = $dirroot . '/' . $file . '/core/modules/';
}
}
}
diff --git a/htdocs/boxes.php b/htdocs/boxes.php
index 24d0faf6683..d6e7931deed 100644
--- a/htdocs/boxes.php
+++ b/htdocs/boxes.php
@@ -204,12 +204,12 @@ class InfoBox
{
$boxname = $regs[1];
$module = $regs[2];
- $sourcefile = dol_buildpath("/".$module."/includes/boxes/".$boxname.".php");
+ $sourcefile = dol_buildpath("/".$module."/core/boxes/".$boxname.".php");
}
else
{
$boxname=preg_replace('/.php$/i','',$obj->file);
- $sourcefile = DOL_DOCUMENT_ROOT."/includes/boxes/".$boxname.".php";
+ $sourcefile = DOL_DOCUMENT_ROOT."/core/boxes/".$boxname.".php";
}
include_once($sourcefile);
@@ -265,12 +265,12 @@ class InfoBox
{
$boxname = $regs[1];
$module = $regs[2];
- $sourcefile = "/".$module."/includes/boxes/".$boxname.".php";
+ $sourcefile = "/".$module."/core/boxes/".$boxname.".php";
}
else
{
$boxname=preg_replace('/.php$/i','',$obj->file);
- $sourcefile = "/includes/boxes/".$boxname.".php";
+ $sourcefile = "/core/boxes/".$boxname.".php";
}
dol_include_once($sourcefile);
diff --git a/htdocs/comm/action/rapport/index.php b/htdocs/comm/action/rapport/index.php
index 6ecc759472b..25d0403f3c4 100644
--- a/htdocs/comm/action/rapport/index.php
+++ b/htdocs/comm/action/rapport/index.php
@@ -28,7 +28,7 @@ require("../../../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/core/lib/files.lib.php");
require_once(DOL_DOCUMENT_ROOT."/contact/class/contact.class.php");
require_once(DOL_DOCUMENT_ROOT."/comm/action/class/actioncomm.class.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/action/rapport.pdf.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/action/rapport.pdf.php");
$sortfield = GETPOST("sortfield",'alpha');
$sortorder = GETPOST("sortorder",'alpha');
diff --git a/htdocs/comm/addpropal.php b/htdocs/comm/addpropal.php
index 0b844539bca..2cecb224515 100644
--- a/htdocs/comm/addpropal.php
+++ b/htdocs/comm/addpropal.php
@@ -27,7 +27,7 @@
require("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT.'/comm/propal/class/propal.class.php');
-require_once(DOL_DOCUMENT_ROOT.'/includes/modules/propale/modules_propale.php');
+require_once(DOL_DOCUMENT_ROOT.'/core/modules/propale/modules_propale.php');
if ($conf->projet->enabled)
{
require_once(DOL_DOCUMENT_ROOT."/projet/class/project.class.php");
@@ -82,9 +82,9 @@ if ($_GET["action"] == 'create')
$obj = $conf->global->PROPALE_ADDON;
if ($obj)
{
- if (! empty($conf->global->PROPALE_ADDON) && is_readable(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
+ if (! empty($conf->global->PROPALE_ADDON) && is_readable(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
{
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php");
$modPropale = new $obj;
$numpr = $modPropale->getNextValue($soc,$propal);
}
diff --git a/htdocs/comm/mailing/cibles.php b/htdocs/comm/mailing/cibles.php
index 543537efe41..8b4516bfd63 100644
--- a/htdocs/comm/mailing/cibles.php
+++ b/htdocs/comm/mailing/cibles.php
@@ -36,7 +36,7 @@ if (! $user->rights->mailing->lire || $user->societe_id > 0)
accessforbidden();
-$dirmod=DOL_DOCUMENT_ROOT."/includes/modules/mailings";
+$dirmod=DOL_DOCUMENT_ROOT."/core/modules/mailings";
$mesg = '';
@@ -69,7 +69,7 @@ if ($_GET["action"] == 'add')
$var=true;
foreach ($conf->file->dol_document_root as $dirmod)
{
- $dir=$dirmod."/includes/modules/mailings/";
+ $dir=$dirmod."/core/modules/mailings/";
if (is_dir($dir))
{
@@ -229,7 +229,7 @@ if ($mil->fetch($_REQUEST["id"]) >= 0)
$var=true;
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir=$dirroot."/includes/modules/mailings/";
+ $dir=$dirroot."/core/modules/mailings/";
if (is_dir($dir))
{
diff --git a/htdocs/comm/mailing/index.php b/htdocs/comm/mailing/index.php
index 34a45e23487..ba9c9371213 100644
--- a/htdocs/comm/mailing/index.php
+++ b/htdocs/comm/mailing/index.php
@@ -67,7 +67,7 @@ print "
\n";
print '
';
print '| '.$langs->trans("TargetsStatistics").' |
';
-$dir=DOL_DOCUMENT_ROOT."/includes/modules/mailings";
+$dir=DOL_DOCUMENT_ROOT."/core/modules/mailings";
$handle=opendir($dir);
$var=True;
diff --git a/htdocs/comm/propal.php b/htdocs/comm/propal.php
index 10b5e9ef4a5..f202b1ce7d7 100644
--- a/htdocs/comm/propal.php
+++ b/htdocs/comm/propal.php
@@ -30,7 +30,7 @@
require("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT.'/comm/propal/class/propal.class.php');
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/propale/modules_propale.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/propale/modules_propale.php");
require_once(DOL_DOCUMENT_ROOT.'/comm/action/class/actioncomm.class.php');
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formother.class.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formfile.class.php");
diff --git a/htdocs/comm/propal/class/propal.class.php b/htdocs/comm/propal/class/propal.class.php
index b025757364e..e553641f54c 100644
--- a/htdocs/comm/propal/class/propal.class.php
+++ b/htdocs/comm/propal/class/propal.class.php
@@ -885,7 +885,7 @@ class Propal extends CommonObject
$objsoc->fetch($object->socid);
- if (empty($conf->global->PROPALE_ADDON) || ! is_readable(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
+ if (empty($conf->global->PROPALE_ADDON) || ! is_readable(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php"))
{
$this->error='ErrorSetupNotComplete';
return -1;
@@ -900,7 +900,7 @@ class Propal extends CommonObject
$object->ref_client = '';
// Set ref
- require_once(DOL_DOCUMENT_ROOT ."/includes/modules/propale/".$conf->global->PROPALE_ADDON.".php");
+ require_once(DOL_DOCUMENT_ROOT ."/core/modules/propale/".$conf->global->PROPALE_ADDON.".php");
$obj = $conf->global->PROPALE_ADDON;
$modPropale = new $obj;
$object->ref = $modPropale->getNextValue($objsoc,$object);
@@ -2275,7 +2275,7 @@ class Propal extends CommonObject
global $conf, $db, $langs;
$langs->load("propal");
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/propale/";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/propale/";
if (! empty($conf->global->PROPALE_ADDON))
{
diff --git a/htdocs/commande/class/commande.class.php b/htdocs/commande/class/commande.class.php
index 3cbe3d57927..e40ef308228 100644
--- a/htdocs/commande/class/commande.class.php
+++ b/htdocs/commande/class/commande.class.php
@@ -126,7 +126,7 @@ class Commande extends CommonObject
global $db, $langs, $conf;
$langs->load("order");
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/commande";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/commande";
if (! empty($conf->global->COMMANDE_ADDON))
{
diff --git a/htdocs/commande/fiche.php b/htdocs/commande/fiche.php
index 4139763c5a1..9330ece6129 100644
--- a/htdocs/commande/fiche.php
+++ b/htdocs/commande/fiche.php
@@ -30,7 +30,7 @@
require("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formfile.class.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formorder.class.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/commande/modules_commande.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/commande/modules_commande.php");
require_once(DOL_DOCUMENT_ROOT.'/commande/class/commande.class.php');
require_once(DOL_DOCUMENT_ROOT.'/comm/action/class/actioncomm.class.php');
require_once(DOL_DOCUMENT_ROOT."/core/lib/order.lib.php");
@@ -852,7 +852,7 @@ if ($action == 'builddoc') // In get or post
{
/*
* Generate order document
- * define into /includes/modules/commande/modules_commande.php
+ * define into /core/modules/commande/modules_commande.php
*/
// Sauvegarde le dernier modele choisi pour generer un document
@@ -1285,7 +1285,7 @@ if ($action == 'create' && $user->rights->commande->creer)
print '| '.$langs->trans('Model').' | ';
print '';
// pdf
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/commande/modules_commande.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/commande/modules_commande.php');
$liste=ModelePDFCommandes::liste_modeles($db);
print $html->selectarray('model',$liste,$conf->global->COMMANDE_ADDON_PDF);
print " |
";
diff --git a/htdocs/compta/dons/fiche.php b/htdocs/compta/dons/fiche.php
index e688274d4ee..0051d74f56a 100644
--- a/htdocs/compta/dons/fiche.php
+++ b/htdocs/compta/dons/fiche.php
@@ -23,7 +23,7 @@
*/
require("../../main.inc.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/dons/modules_don.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/dons/modules_don.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formfile.class.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formcompany.class.php");
require_once(DOL_DOCUMENT_ROOT."/compta/dons/class/don.class.php");
diff --git a/htdocs/compta/facture.php b/htdocs/compta/facture.php
index 0d43862bc08..cf2943d0404 100644
--- a/htdocs/compta/facture.php
+++ b/htdocs/compta/facture.php
@@ -30,7 +30,7 @@
require('../main.inc.php');
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formfile.class.php");
require_once(DOL_DOCUMENT_ROOT."/core/class/html.formother.class.php");
-require_once(DOL_DOCUMENT_ROOT.'/includes/modules/facture/modules_facture.php');
+require_once(DOL_DOCUMENT_ROOT.'/core/modules/facture/modules_facture.php');
require_once(DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php');
require_once(DOL_DOCUMENT_ROOT.'/core/class/discount.class.php');
require_once(DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php');
@@ -1722,7 +1722,7 @@ if ($action == 'create')
// Modele PDF
print '| '.$langs->trans('Model').' | ';
print '';
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/facture/modules_facture.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/facture/modules_facture.php');
$liste=ModelePDFFactures::liste_modeles($db);
print $html->selectarray('model',$liste,$conf->global->FACTURE_ADDON_PDF);
print " |
";
diff --git a/htdocs/compta/facture/class/facture.class.php b/htdocs/compta/facture/class/facture.class.php
index 31da3914858..78591487591 100644
--- a/htdocs/compta/facture/class/facture.class.php
+++ b/htdocs/compta/facture/class/facture.class.php
@@ -2557,7 +2557,7 @@ class Facture extends CommonObject
// Include file with class
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot."/includes/modules/facture/";
+ $dir = $dirroot."/core/modules/facture/";
// Load file with numbering class (if found)
$mybool|=@include_once($dir.$file);
}
@@ -2570,7 +2570,7 @@ class Facture extends CommonObject
// Include file with class
foreach ($conf->file->dol_document_root as $dirroot)
{
- $dir = $dirroot."/includes/modules/facture/";
+ $dir = $dirroot."/core/modules/facture/";
// Load file with numbering class (if found)
$mybool|=@include_once($dir.$file);
}
diff --git a/htdocs/compta/paiement/cheque/class/remisecheque.class.php b/htdocs/compta/paiement/cheque/class/remisecheque.class.php
index e7890ec980a..dfe19ad5988 100644
--- a/htdocs/compta/paiement/cheque/class/remisecheque.class.php
+++ b/htdocs/compta/paiement/cheque/class/remisecheque.class.php
@@ -479,7 +479,7 @@ class RemiseCheque extends CommonObject
dol_syslog("RemiseCheque::generatePdf model=".$model." id=".$this->id, LOG_DEBUG);
- $dir=DOL_DOCUMENT_ROOT ."/includes/modules/cheque/pdf/";
+ $dir=DOL_DOCUMENT_ROOT ."/core/modules/cheque/pdf/";
// Charge le modele
$file = "pdf_".$model.".class.php";
diff --git a/htdocs/compta/paiement/fiche.php b/htdocs/compta/paiement/fiche.php
index ae1223a1e01..b0b9dc690df 100644
--- a/htdocs/compta/paiement/fiche.php
+++ b/htdocs/compta/paiement/fiche.php
@@ -28,7 +28,7 @@
require("../../main.inc.php");
require_once(DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php');
require_once(DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php');
-require_once(DOL_DOCUMENT_ROOT ."/includes/modules/facture/modules_facture.php");
+require_once(DOL_DOCUMENT_ROOT ."/core/modules/facture/modules_facture.php");
if ($conf->banque->enabled) require_once(DOL_DOCUMENT_ROOT.'/compta/bank/class/account.class.php');
$langs->load('bills');
diff --git a/htdocs/compta/paiement/rapport.php b/htdocs/compta/paiement/rapport.php
index 18309fd1713..5a939f37365 100644
--- a/htdocs/compta/paiement/rapport.php
+++ b/htdocs/compta/paiement/rapport.php
@@ -23,7 +23,7 @@
*/
require("../../main.inc.php");
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/rapport/pdf_paiement.class.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/rapport/pdf_paiement.class.php");
require_once(DOL_DOCUMENT_ROOT."/core/lib/files.lib.php");
// Security check
diff --git a/htdocs/compta/payment_sc/fiche.php b/htdocs/compta/payment_sc/fiche.php
index d69efe561ab..577fe00342b 100644
--- a/htdocs/compta/payment_sc/fiche.php
+++ b/htdocs/compta/payment_sc/fiche.php
@@ -29,7 +29,7 @@ require('../../main.inc.php');
require_once(DOL_DOCUMENT_ROOT."/compta/sociales/class/chargesociales.class.php");
require_once(DOL_DOCUMENT_ROOT."/compta/sociales/class/paymentsocialcontribution.class.php");
require_once(DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php');
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/facture/modules_facture.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/facture/modules_facture.php");
if ($conf->banque->enabled) require_once(DOL_DOCUMENT_ROOT.'/compta/bank/class/account.class.php');
$langs->load('bills');
diff --git a/htdocs/compta/prelevement/demandes.php b/htdocs/compta/prelevement/demandes.php
index 5bd3db7b996..82ab1bb4402 100644
--- a/htdocs/compta/prelevement/demandes.php
+++ b/htdocs/compta/prelevement/demandes.php
@@ -23,7 +23,7 @@
* \brief Page to list withdraw requests
*/
require("../bank/pre.inc.php");
-require_once DOL_DOCUMENT_ROOT."/includes/modules/modPrelevement.class.php";
+require_once DOL_DOCUMENT_ROOT."/core/modules/modPrelevement.class.php";
require_once DOL_DOCUMENT_ROOT."/compta/facture/class/facture.class.php";
require_once DOL_DOCUMENT_ROOT."/societe/class/societe.class.php";
diff --git a/htdocs/conf/conf.php.example b/htdocs/conf/conf.php.example
index 9d59caf0cc4..61366fe7219 100644
--- a/htdocs/conf/conf.php.example
+++ b/htdocs/conf/conf.php.example
@@ -156,7 +156,7 @@ $dolibarr_main_db_collation='latin1_swedish_ci';
# This parameter contains the way authentication is done.
# If value "ldap" is used, you must also set parameters dolibarr_main_auth_ldap_*
# Default value: dolibarr
-# Possible values: Any values found in files in htdocs/includes/login directory after
+# Possible values: Any values found in files in htdocs/core/login directory after
# the "function_" string and before the ".php" string. You can also separate several
# values using a ",". In this case, Dolibarr will check login/pass for each value in
# order defined into value. However, note that this can't work with all values.
diff --git a/htdocs/contrat/class/contrat.class.php b/htdocs/contrat/class/contrat.class.php
index 560941a64e3..25d6bdbe883 100644
--- a/htdocs/contrat/class/contrat.class.php
+++ b/htdocs/contrat/class/contrat.class.php
@@ -95,7 +95,7 @@ class Contrat extends CommonObject
global $db, $langs, $conf;
$langs->load("contract");
- $dir = DOL_DOCUMENT_ROOT . "/includes/modules/contract";
+ $dir = DOL_DOCUMENT_ROOT . "/core/modules/contract";
if (empty($conf->global->CONTRACT_ADDON))
{
diff --git a/htdocs/contrat/fiche.php b/htdocs/contrat/fiche.php
index f32998c3c4d..beccf9a85f8 100644
--- a/htdocs/contrat/fiche.php
+++ b/htdocs/contrat/fiche.php
@@ -28,7 +28,7 @@
require ("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/core/lib/date.lib.php");
require_once(DOL_DOCUMENT_ROOT.'/core/lib/contract.lib.php');
-require_once(DOL_DOCUMENT_ROOT."/includes/modules/contract/modules_contract.php");
+require_once(DOL_DOCUMENT_ROOT."/core/modules/contract/modules_contract.php");
if ($conf->projet->enabled) require_once(DOL_DOCUMENT_ROOT."/projet/class/project.class.php");
if ($conf->propal->enabled) require_once(DOL_DOCUMENT_ROOT."/comm/propal/class/propal.class.php");
if ($conf->contrat->enabled) require_once(DOL_DOCUMENT_ROOT."/contrat/class/contrat.class.php");
diff --git a/htdocs/includes/boxes/box_actions.php b/htdocs/core/boxes/box_actions.php
similarity index 97%
rename from htdocs/includes/boxes/box_actions.php
rename to htdocs/core/boxes/box_actions.php
index 1b27b7dceb9..d8a9548f73d 100644
--- a/htdocs/includes/boxes/box_actions.php
+++ b/htdocs/core/boxes/box_actions.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_actions.php
+ * \file htdocs/core/boxes/box_actions.php
* \ingroup actions
* \brief Module to build boxe for events
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_actions extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_bookmarks.php b/htdocs/core/boxes/box_bookmarks.php
similarity index 96%
rename from htdocs/includes/boxes/box_bookmarks.php
rename to htdocs/core/boxes/box_bookmarks.php
index dbf1585e022..aa31aa3cf7d 100644
--- a/htdocs/includes/boxes/box_bookmarks.php
+++ b/htdocs/core/boxes/box_bookmarks.php
@@ -16,11 +16,11 @@
*/
/**
- * \file htdocs/includes/boxes/box_bookmarks.php
+ * \file htdocs/core/boxes/box_bookmarks.php
* \ingroup bookmark
* \brief Module to generate box of bookmarks list
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_bookmarks extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_clients.php b/htdocs/core/boxes/box_clients.php
similarity index 97%
rename from htdocs/includes/boxes/box_clients.php
rename to htdocs/core/boxes/box_clients.php
index 33feb5e4910..c9db0650c43 100644
--- a/htdocs/includes/boxes/box_clients.php
+++ b/htdocs/core/boxes/box_clients.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_clients.php
+ * \file htdocs/core/boxes/box_clients.php
* \ingroup societes
* \brief Module de generation de l'affichage de la box clients
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_clients extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_commandes.php b/htdocs/core/boxes/box_commandes.php
similarity index 97%
rename from htdocs/includes/boxes/box_commandes.php
rename to htdocs/core/boxes/box_commandes.php
index b5fdd6cfb4d..8aac9fada59 100644
--- a/htdocs/includes/boxes/box_commandes.php
+++ b/htdocs/core/boxes/box_commandes.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_commandes.php
+ * \file htdocs/core/boxes/box_commandes.php
* \ingroup commande
* \brief Module de generation de l'affichage de la box commandes
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_commandes extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_comptes.php b/htdocs/core/boxes/box_comptes.php
similarity index 97%
rename from htdocs/includes/boxes/box_comptes.php
rename to htdocs/core/boxes/box_comptes.php
index be8e3abd56e..fc70f640161 100644
--- a/htdocs/includes/boxes/box_comptes.php
+++ b/htdocs/core/boxes/box_comptes.php
@@ -18,11 +18,11 @@
*/
/**
- * \file htdocs/includes/boxes/box_comptes.php
+ * \file htdocs/core/boxes/box_comptes.php
* \ingroup banque
* \brief Module to generate box for bank accounts
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
include_once(DOL_DOCUMENT_ROOT."/compta/bank/class/account.class.php");
diff --git a/htdocs/includes/boxes/box_contacts.php b/htdocs/core/boxes/box_contacts.php
similarity index 97%
rename from htdocs/includes/boxes/box_contacts.php
rename to htdocs/core/boxes/box_contacts.php
index 8ae7c6a81d6..0371e821d22 100755
--- a/htdocs/includes/boxes/box_contacts.php
+++ b/htdocs/core/boxes/box_contacts.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_contacts.php
+ * \file htdocs/core/boxes/box_contacts.php
* \ingroup societes
* \brief Module to show box of contacts
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
include_once(DOL_DOCUMENT_ROOT."/contact/class/contact.class.php");
diff --git a/htdocs/includes/boxes/box_contracts.php b/htdocs/core/boxes/box_contracts.php
similarity index 97%
rename from htdocs/includes/boxes/box_contracts.php
rename to htdocs/core/boxes/box_contracts.php
index 9da5205c1be..223d9259d8f 100644
--- a/htdocs/includes/boxes/box_contracts.php
+++ b/htdocs/core/boxes/box_contracts.php
@@ -16,12 +16,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_contracts.php
+ * \file htdocs/core/boxes/box_contracts.php
* \ingroup contracts
* \brief Module de generation de l'affichage de la box contracts
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_contracts extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_external_rss.php b/htdocs/core/boxes/box_external_rss.php
similarity index 97%
rename from htdocs/includes/boxes/box_external_rss.php
rename to htdocs/core/boxes/box_external_rss.php
index cf159c41599..dfaf342f5e8 100644
--- a/htdocs/includes/boxes/box_external_rss.php
+++ b/htdocs/core/boxes/box_external_rss.php
@@ -19,13 +19,13 @@
*/
/**
- * \file htdocs/includes/boxes/box_external_rss.php
+ * \file htdocs/core/boxes/box_external_rss.php
* \ingroup external_rss
* \brief Fichier de gestion d'une box pour le module external_rss
*/
include_once(DOL_DOCUMENT_ROOT."/core/class/rssparser.class.php");
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_external_rss extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_factures.php b/htdocs/core/boxes/box_factures.php
similarity index 97%
rename from htdocs/includes/boxes/box_factures.php
rename to htdocs/core/boxes/box_factures.php
index e917a42e6ed..b7359c19932 100644
--- a/htdocs/includes/boxes/box_factures.php
+++ b/htdocs/core/boxes/box_factures.php
@@ -18,11 +18,11 @@
*/
/**
- * \file htdocs/includes/boxes/box_factures.php
+ * \file htdocs/core/boxes/box_factures.php
* \ingroup factures
* \brief Module de generation de l'affichage de la box factures
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_factures extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_factures_fourn.php b/htdocs/core/boxes/box_factures_fourn.php
similarity index 97%
rename from htdocs/includes/boxes/box_factures_fourn.php
rename to htdocs/core/boxes/box_factures_fourn.php
index dd28066c6ef..5cbb0af5cd9 100644
--- a/htdocs/includes/boxes/box_factures_fourn.php
+++ b/htdocs/core/boxes/box_factures_fourn.php
@@ -18,11 +18,11 @@
*/
/**
- * \file htdocs/includes/boxes/box_factures_fourn.php
+ * \file htdocs/core/boxes/box_factures_fourn.php
* \ingroup supplier
* \brief Fichier de gestion d'une box des factures fournisseurs
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_factures_fourn extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_factures_fourn_imp.php b/htdocs/core/boxes/box_factures_fourn_imp.php
similarity index 97%
rename from htdocs/includes/boxes/box_factures_fourn_imp.php
rename to htdocs/core/boxes/box_factures_fourn_imp.php
index 1f1d7430a7d..61363d2bcac 100644
--- a/htdocs/includes/boxes/box_factures_fourn_imp.php
+++ b/htdocs/core/boxes/box_factures_fourn_imp.php
@@ -17,11 +17,11 @@
*/
/**
- * \file htdocs/includes/boxes/box_factures_fourn_imp.php
+ * \file htdocs/core/boxes/box_factures_fourn_imp.php
* \ingroup fournisseur
* \brief Fichier de gestion d'une box des factures fournisseurs impayees
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_factures_fourn_imp extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_factures_imp.php b/htdocs/core/boxes/box_factures_imp.php
similarity index 97%
rename from htdocs/includes/boxes/box_factures_imp.php
rename to htdocs/core/boxes/box_factures_imp.php
index 3b268185e2c..57b0e2cb722 100644
--- a/htdocs/includes/boxes/box_factures_imp.php
+++ b/htdocs/core/boxes/box_factures_imp.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_factures_imp.php
+ * \file htdocs/core/boxes/box_factures_imp.php
* \ingroup factures
* \brief Module de generation de l'affichage de la box factures impayees
*/
-require_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+require_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
require_once(DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php');
diff --git a/htdocs/includes/boxes/box_fournisseurs.php b/htdocs/core/boxes/box_fournisseurs.php
similarity index 97%
rename from htdocs/includes/boxes/box_fournisseurs.php
rename to htdocs/core/boxes/box_fournisseurs.php
index 5528066c158..5ca61023b71 100644
--- a/htdocs/includes/boxes/box_fournisseurs.php
+++ b/htdocs/core/boxes/box_fournisseurs.php
@@ -17,12 +17,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_fournisseurs.php
+ * \file htdocs/core/boxes/box_fournisseurs.php
* \ingroup fournisseurs
* \brief Module to generate box of suppliers
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_fournisseurs extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_members.php b/htdocs/core/boxes/box_members.php
similarity index 96%
rename from htdocs/includes/boxes/box_members.php
rename to htdocs/core/boxes/box_members.php
index 0cba1596a3c..8b3cc143b33 100755
--- a/htdocs/includes/boxes/box_members.php
+++ b/htdocs/core/boxes/box_members.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_members.php
+ * \file htdocs/core/boxes/box_members.php
* \ingroup societes
* \brief Module de generation de l'affichage de la box clients
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_members extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_osc_client.php b/htdocs/core/boxes/box_osc_client.php
similarity index 96%
rename from htdocs/includes/boxes/box_osc_client.php
rename to htdocs/core/boxes/box_osc_client.php
index f9ea1fb4c40..a2a539f22ac 100644
--- a/htdocs/includes/boxes/box_osc_client.php
+++ b/htdocs/core/boxes/box_osc_client.php
@@ -17,12 +17,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_osc_client.php
+ * \file htdocs/core/boxes/box_osc_client.php
* \ingroup osc
* \brief Module to generate box of shop customers
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_osc_clients extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_produits.php b/htdocs/core/boxes/box_produits.php
similarity index 97%
rename from htdocs/includes/boxes/box_produits.php
rename to htdocs/core/boxes/box_produits.php
index 166711e8e2e..711ee033a8c 100644
--- a/htdocs/includes/boxes/box_produits.php
+++ b/htdocs/core/boxes/box_produits.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_produits.php
+ * \file htdocs/core/boxes/box_produits.php
* \ingroup produits,services
* \brief Module to generate box of last products/services
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
include_once(DOL_DOCUMENT_ROOT."/product/class/product.class.php");
diff --git a/htdocs/includes/boxes/box_propales.php b/htdocs/core/boxes/box_propales.php
similarity index 97%
rename from htdocs/includes/boxes/box_propales.php
rename to htdocs/core/boxes/box_propales.php
index 64d7508ff6b..91bc157ea80 100644
--- a/htdocs/includes/boxes/box_propales.php
+++ b/htdocs/core/boxes/box_propales.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_propales.php
+ * \file htdocs/core/boxes/box_propales.php
* \ingroup propales
* \brief Module de generation de l'affichage de la box propales
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_propales extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/box_prospect.php b/htdocs/core/boxes/box_prospect.php
similarity index 97%
rename from htdocs/includes/boxes/box_prospect.php
rename to htdocs/core/boxes/box_prospect.php
index c34e18e0028..3e4c3c67a0b 100644
--- a/htdocs/includes/boxes/box_prospect.php
+++ b/htdocs/core/boxes/box_prospect.php
@@ -18,13 +18,13 @@
*/
/**
- * \file htdocs/includes/boxes/box_prospect.php
+ * \file htdocs/core/boxes/box_prospect.php
* \ingroup societe
* \brief Module to generate the last prospects box.
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
include_once(DOL_DOCUMENT_ROOT."/comm/prospect/class/prospect.class.php");
diff --git a/htdocs/includes/boxes/box_services_vendus.php b/htdocs/core/boxes/box_services_vendus.php
similarity index 97%
rename from htdocs/includes/boxes/box_services_vendus.php
rename to htdocs/core/boxes/box_services_vendus.php
index 2ccf675ed23..067deee6d1f 100644
--- a/htdocs/includes/boxes/box_services_vendus.php
+++ b/htdocs/core/boxes/box_services_vendus.php
@@ -18,12 +18,12 @@
*/
/**
- * \file htdocs/includes/boxes/box_services_vendus.php
+ * \file htdocs/core/boxes/box_services_vendus.php
* \ingroup produits,services
* \brief Module de generation de l'affichage de la box services_vendus
*/
-include_once(DOL_DOCUMENT_ROOT."/includes/boxes/modules_boxes.php");
+include_once(DOL_DOCUMENT_ROOT."/core/boxes/modules_boxes.php");
class box_services_vendus extends ModeleBoxes {
diff --git a/htdocs/includes/boxes/modules_boxes.php b/htdocs/core/boxes/modules_boxes.php
similarity index 99%
rename from htdocs/includes/boxes/modules_boxes.php
rename to htdocs/core/boxes/modules_boxes.php
index d899f0e0ce3..e03ec6aa778 100644
--- a/htdocs/includes/boxes/modules_boxes.php
+++ b/htdocs/core/boxes/modules_boxes.php
@@ -17,7 +17,7 @@
*/
/**
- * \file htdocs/includes/boxes/modules_boxes.php
+ * \file htdocs/core/boxes/modules_boxes.php
* \ingroup facture
* \brief Fichier contenant la classe mere des boites
*/
diff --git a/htdocs/core/class/conf.class.php b/htdocs/core/class/conf.class.php
index 9b21460fef5..44a366f876c 100644
--- a/htdocs/core/class/conf.class.php
+++ b/htdocs/core/class/conf.class.php
@@ -90,7 +90,7 @@ class Conf
dol_syslog("Conf::setValues");
// Directory of core triggers
- $this->triggers_modules[] = "/includes/triggers"; // Default relative path to triggers file
+ $this->triggers_modules[] = "/core/triggers"; // Default relative path to triggers file
// Avoid warning if not defined
if (empty($this->db->dolibarr_main_db_encryption)) $this->db->dolibarr_main_db_encryption=0;
@@ -142,13 +142,13 @@ class Conf
elseif (preg_match('/^MAIN_MODULE_([A-Z_]+)_TRIGGERS$/i',$key,$reg))
{
$modulename = strtolower($reg[1]);
- $this->triggers_modules[] = '/'.$modulename.'/includes/triggers/';
+ $this->triggers_modules[] = '/'.$modulename.'/core/triggers/';
}
// If this is constant for login method activated by a module
elseif (preg_match('/^MAIN_MODULE_([A-Z_]+)_LOGIN_METHOD$/i',$key,$reg))
{
$modulename = strtolower($reg[1]);
- $this->login_method_modules[] = dol_buildpath('/'.$modulename.'/includes/login/');
+ $this->login_method_modules[] = dol_buildpath('/'.$modulename.'/core/login/');
}
// If this is constant for hook activated by a module. Value is list of hooked tabs separated with :
elseif (preg_match('/^MAIN_MODULE_([A-Z_]+)_HOOKS$/i',$key,$reg))
diff --git a/htdocs/core/class/html.form.class.php b/htdocs/core/class/html.form.class.php
index 5d36d245abb..79d3dc57eb6 100644
--- a/htdocs/core/class/html.form.class.php
+++ b/htdocs/core/class/html.form.class.php
@@ -3188,7 +3188,7 @@ class Form
// Generate the date part, depending on the use or not of the javascript calendar
if (empty($conf->global->MAIN_POPUP_CALENDAR) || $conf->global->MAIN_POPUP_CALENDAR == "eldy")
{
- $base=DOL_URL_ROOT.'/lib/';
+ $base=DOL_URL_ROOT.'/core/lib/';
$reset_scripts .= 'resetDP(\''.$base.'\',\''.$prefix.'\',\''.$langs->trans("FormatDateShortJava").'\',\''.$langs->defaultlang.'\');';
}
else
diff --git a/htdocs/core/class/html.formfile.class.php b/htdocs/core/class/html.formfile.class.php
index 52580882ccc..df036a26f59 100644
--- a/htdocs/core/class/html.formfile.class.php
+++ b/htdocs/core/class/html.formfile.class.php
@@ -221,7 +221,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/societe/modules_societe.class.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/societe/modules_societe.class.php');
$modellist=ModeleThirdPartyDoc::liste_modeles($this->db);
}
}
@@ -230,7 +230,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/propale/modules_propale.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/propale/modules_propale.php');
$modellist=ModelePDFPropales::liste_modeles($this->db);
}
}
@@ -239,7 +239,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/commande/modules_commande.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/commande/modules_commande.php');
$modellist=ModelePDFCommandes::liste_modeles($this->db);
}
}
@@ -248,7 +248,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/expedition/pdf/ModelePdfExpedition.class.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/expedition/pdf/ModelePdfExpedition.class.php');
$modellist=ModelePDFExpedition::liste_modeles($this->db);
}
}
@@ -257,7 +257,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/livraison/modules_livraison.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/livraison/modules_livraison.php');
$modellist=ModelePDFDeliveryOrder::liste_modeles($this->db);
}
}
@@ -266,7 +266,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/fichinter/modules_fichinter.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/fichinter/modules_fichinter.php');
$modellist=ModelePDFFicheinter::liste_modeles($this->db);
}
}
@@ -275,7 +275,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/facture/modules_facture.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/facture/modules_facture.php');
$modellist=ModelePDFFactures::liste_modeles($this->db);
// This is to allow to join external files to invoices
@@ -295,7 +295,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/project/modules_project.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/project/modules_project.php');
$modellist=ModelePDFProjects::liste_modeles($this->db);
}
}
@@ -304,7 +304,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/export/modules_export.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/export/modules_export.php');
$modellist=ModeleExports::liste_modeles($this->db);
}
}
@@ -313,7 +313,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/supplier_order/modules_commandefournisseur.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/supplier_order/modules_commandefournisseur.php');
$modellist=ModelePDFSuppliersOrders::liste_modeles($this->db);
}
}
@@ -322,7 +322,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/supplier_invoice/modules_facturefournisseur.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/supplier_invoice/modules_facturefournisseur.php');
$modellist=ModelePDFSuppliersInvoices::liste_modeles($this->db);
}
}
@@ -331,7 +331,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/cheque/pdf/modules_chequereceipts.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/cheque/pdf/modules_chequereceipts.php');
$modellist=ModeleChequeReceipts::liste_modeles($this->db);
}
}
@@ -340,7 +340,7 @@ class FormFile
if (is_array($genallowed)) $modellist=$genallowed;
else
{
- include_once(DOL_DOCUMENT_ROOT.'/includes/modules/dons/modules_don.php');
+ include_once(DOL_DOCUMENT_ROOT.'/core/modules/dons/modules_don.php');
$modellist=ModeleDon::liste_modeles($this->db);
}
}
@@ -351,7 +351,7 @@ class FormFile
else
{
// Generic feature, for external modules
- $file=dol_buildpath('/includes/modules/'.$modulepart.'/modules_'.$modulepart.'.php',0);
+ $file=dol_buildpath('/core/modules/'.$modulepart.'/modules_'.$modulepart.'.php',0);
if (file_exists($file))
{
$res=include_once($file);
diff --git a/htdocs/core/class/html.formother.class.php b/htdocs/core/class/html.formother.class.php
index 442559bb851..679485a4a07 100644
--- a/htdocs/core/class/html.formother.class.php
+++ b/htdocs/core/class/html.formother.class.php
@@ -417,7 +417,7 @@ class FormOther
/*
// No list of colors forced, we can suggest any color
print "\n".'| ';
- print ''."\n";
+ print ''."\n";
print ' |
diff --git a/dev/skeletons/modMyModule.class.php b/dev/skeletons/modMyModule.class.php
index 27f44a01f22..2beb4eee7f1 100644
--- a/dev/skeletons/modMyModule.class.php
+++ b/dev/skeletons/modMyModule.class.php
@@ -20,12 +20,12 @@
/**
* \defgroup mymodule Module MyModule
* \brief Example of a module descriptor.
* Such a file must be copied into htdocs/mymodule/includes/modules directory.
* \file htdocs/mymodule/includes/modules/modMyModule.class.php
* \ingroup mymodule
* \brief Description and activation file for module MyModule
*/
-include_once(DOL_DOCUMENT_ROOT ."/includes/modules/DolibarrModules.class.php");
+include_once(DOL_DOCUMENT_ROOT ."/core/modules/DolibarrModules.class.php");
/**
@@ -69,7 +69,7 @@ class modMyModule extends DolibarrModules
// If file is in module/img directory under name object_pictovalue.png, use this->picto='pictovalue@module'
$this->picto='generic';
// Defined if the directory /mymodule/includes/triggers/ contains triggers or not
$this->triggers = 0;
// Data directories to create when module is enabled.
@@ -139,7 +139,7 @@ class modMyModule extends DolibarrModules
*/
// Boxes
// Add here list of php file(s) stored in includes/boxes that contains class to show a box.
$this->boxes = array(); // List of boxes
$r=0;
// Example:
@@ -20,12 +20,12 @@
* \defgroup mymodule Module MyModule
* \brief Example of a module descriptor.
- * Such a file must be copied into htdocs/mymodule/includes/modules directory.
- * \file htdocs/mymodule/includes/modules/modMyModule.class.php
+ * Such a file must be copied into htdocs/mymodule/core/modules directory.
+ * \file htdocs/mymodule/core/modules/modMyModule.class.php
* \ingroup mymodule
* \brief Description and activation file for module MyModule
@@ -69,7 +69,7 @@ class modMyModule extends DolibarrModules
// If file is in module/img directory under name object_pictovalue.png, use this->picto='pictovalue@module'
$this->picto='generic';
- // Defined if the directory /mymodule/includes/triggers/ contains triggers or not
+ // Defined if the directory /mymodule/core/triggers/ contains triggers or not
$this->triggers = 0;
// Data directories to create when module is enabled.
@@ -139,7 +139,7 @@ class modMyModule extends DolibarrModules
*/
// Boxes
- // Add here list of php file(s) stored in includes/boxes that contains class to show a box.
+ // Add here list of php file(s) stored in core/boxes that contains class to show a box.
$this->boxes = array(); // List of boxes
$r=0;